@@ -1,6 +1,24 @@
+/* 
+   Copyright (C) 2003-2008 FreeIPMI Core Team
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
+*/
+
 #if HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -14,6 +32,10 @@
 #include "bmc-config-validate.h"
 #include "bmc-config-utils.h"
 
+#include "freeipmi-portability.h"
+#include "pstdout.h"
+#include "tool-fiid-wrappers.h"
+
 /* convenience struct */
 struct channel_access
 {
@@ -35,7 +57,7 @@ _channel_info(bmc_config_state_data_t *state_data,
   assert(section_name);
   assert(channel_number);
 
-  if (strstr(section_name, "Lan"))
+  if (stristr(section_name, "Lan"))
     {
       if ((ret = get_lan_channel_number (state_data,
                                          channel_number)) != CONFIG_ERR_SUCCESS)
@@ -72,7 +94,7 @@ _get_key_info(bmc_config_state_data_t *state_data,
     return ret;
 
   /* Must check for Non_Volatile b/c Volatile is a substring of the former */
-  if (strstr(section_name, "Non_Volatile"))
+  if (stristr(section_name, "Non_Volatile"))
     *access_type = IPMI_CHANNEL_ACCESS_GET_NON_VOLATILE;
   else
     *access_type = IPMI_CHANNEL_ACCESS_GET_VOLATILE;
@@ -101,7 +123,7 @@ _set_key_info(bmc_config_state_data_t *state_data,
     return ret;
 
   /* Must check for Non_Volatile b/c Volatile is a substring of the former */
-  if (strstr(section_name, "Non_Volatile"))
+  if (stristr(section_name, "Non_Volatile"))
     *access_type = IPMI_CHANNEL_ACCESS_SET_NON_VOLATILE;
   else
     *access_type = IPMI_CHANNEL_ACCESS_SET_VOLATILE;
@@ -137,48 +159,44 @@ _get_channel_access (bmc_config_state_data_t *state_data,
       goto cleanup;
     }
 
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_get_channel_access_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_get_channel_access_rs);
 
-  if (ipmi_cmd_get_channel_access (state_data->dev,
+  if (ipmi_cmd_get_channel_access (state_data->ipmi_ctx,
                                    channel_number,
                                    access_type,
                                    obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr,
-                "ipmi_cmd_get_channel_access: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr,
+                        "ipmi_cmd_get_channel_access: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
 
-  if (Fiid_obj_get (obj_cmd_rs, "ipmi_messaging_access_mode", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "ipmi_messaging_access_mode", &val);
   ch->access_mode = val;
 
   /* yes/no is backwards here, see ipmi spec */
-  if (Fiid_obj_get (obj_cmd_rs, "user_level_authentication", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "user_level_authentication", &val);
   ch->user_level_authentication = (val ? 0 : 1);
 
   /* yes/no is backwards here, see ipmi spec */
-  if (Fiid_obj_get (obj_cmd_rs, "per_message_authentication", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "per_message_authentication", &val);
   ch->per_message_authentication = (val ? 0 : 1);
 
   /* yes/no is backwards here, see ipmi spec */
-  if (Fiid_obj_get (obj_cmd_rs, "pef_alerting", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "pef_alerting", &val);
   ch->pef_alerting = (val ? 0 : 1);
 
-  if (Fiid_obj_get (obj_cmd_rs, "channel_privilege_level_limit", &val) < 0)
-    goto cleanup;
+  _FIID_OBJ_GET (obj_cmd_rs, "channel_privilege_level_limit", &val);
   ch->channel_privilege_limit = val;
 
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return (rv);
 }
 
@@ -209,12 +227,11 @@ _set_channel_access (bmc_config_state_data_t *state_data,
       goto cleanup;
     }
 
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_set_channel_access_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_set_channel_access_rs);
 
   /* yes/no is backwards several places, see ipmi spec */
 
-  if (ipmi_cmd_set_channel_access (state_data->dev,
+  if (ipmi_cmd_set_channel_access (state_data->ipmi_ctx,
                                    channel_number,
                                    ch->access_mode,
                                    (ch->user_level_authentication ? 0 : 1),
@@ -227,17 +244,19 @@ _set_channel_access (bmc_config_state_data_t *state_data,
                                     : IPMI_PRIVILEGE_LEVEL_LIMIT_SET_NON_VOLATILE),
                                    obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr,
-                "ipmi_cmd_set_channel_access: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr,
+                        "ipmi_cmd_set_channel_access: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
 
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return (rv);
 }
 
@@ -256,7 +275,9 @@ _access_mode_checkout (const char *section_name,
                                  &ch)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output(kv, channel_access_mode_string (ch.access_mode)) < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate,
+                                            kv, 
+                                            channel_access_mode_string (ch.access_mode)) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -304,7 +325,9 @@ _enable_user_level_authentication_checkout (const char *section_name,
     return ret;
 
   /* achu: Backwards values in this command are handled above */
-  if (config_section_update_keyvalue_output(kv, ch.user_level_authentication ? "Yes" : "No") < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate,
+                                            kv,
+                                            ch.user_level_authentication ? "Yes" : "No") < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -352,7 +375,9 @@ _enable_per_message_authentication_checkout (const char *section_name,
     return ret;
 
   /* achu: Backwards values in this command are handled above */
-  if (config_section_update_keyvalue_output(kv, ch.per_message_authentication ? "Yes" : "No") < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate,
+                                            kv, 
+                                            ch.per_message_authentication ? "Yes" : "No") < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -400,7 +425,9 @@ _enable_pef_alerting_checkout (const char *section_name,
     return ret;
 
   /* achu: Backwards values in this command are handled above */
-  if (config_section_update_keyvalue_output(kv, ch.pef_alerting ? "Yes" : "No") < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate,
+                                            kv, 
+                                            ch.pef_alerting ? "Yes" : "No") < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -447,7 +474,9 @@ _channel_privilege_limit_checkout (const char *section_name,
                                  &ch)) != CONFIG_ERR_SUCCESS)
     return ret;
 
-  if (config_section_update_keyvalue_output(kv, privilege_level_string (ch.channel_privilege_limit)) < 0)
+  if (config_section_update_keyvalue_output(state_data->pstate,
+                                            kv,
+                                            privilege_level_string (ch.channel_privilege_limit)) < 0)
     return CONFIG_ERR_FATAL_ERROR;
 
   return CONFIG_ERR_SUCCESS;
@@ -481,96 +510,107 @@ _channel_privilege_limit_commit (const char *section_name,
 
 int
 bmc_config_channel_common_section_get(bmc_config_state_data_t *state_data,
-                                      struct config_section *channel_section)
+                                      struct config_section *channel_section,
+                                      unsigned int verbose_flags)
 {
   assert(state_data);
   assert(channel_section);
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Volatile_Access_Mode",
                               "Possible values: Disabled/Pre_Boot_Only/Always_Available/Shared",
-                              0,
+                              verbose_flags,
                               _access_mode_checkout,
                               _access_mode_commit,
                               channel_access_mode_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Volatile_Enable_User_Level_Auth",
                               "Possible values: Yes/No",
-                              0,
+                              verbose_flags,
                               _enable_user_level_authentication_checkout,
                               _enable_user_level_authentication_commit,
                               config_yes_no_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Volatile_Enable_Per_Message_Auth",
                               "Possible values: Yes/No",
-                              0,
+                              verbose_flags,
                               _enable_per_message_authentication_checkout,
                               _enable_per_message_authentication_commit,
                               config_yes_no_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Volatile_Enable_Pef_Alerting",
                               "Possible values: Yes/No",
-                              0,
+                              verbose_flags,
                               _enable_pef_alerting_checkout,
                               _enable_pef_alerting_commit,
                               config_yes_no_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Volatile_Channel_Privilege_Limit",
                               "Possible values: Callback/User/Operator/Administrator/OEM_Proprietary",
-                              0,
+                              verbose_flags,
                               _channel_privilege_limit_checkout,
                               _channel_privilege_limit_commit,
                               privilege_level_number_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Non_Volatile_Access_Mode",
                               "Possible values: Disabled/Pre_Boot_Only/Always_Available/Shared",
-                              0,
+                              verbose_flags,
                               _access_mode_checkout,
                               _access_mode_commit,
                               channel_access_mode_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Non_Volatile_Enable_User_Level_Auth",
                               "Possible values: Yes/No",
-                              0,
+                              verbose_flags,
                               _enable_user_level_authentication_checkout,
                               _enable_user_level_authentication_commit,
                               config_yes_no_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Non_Volatile_Enable_Per_Message_Auth",
                               "Possible values: Yes/No",
-                              0,
+                              verbose_flags,
                               _enable_per_message_authentication_checkout,
                               _enable_per_message_authentication_commit,
                               config_yes_no_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Non_Volatile_Enable_Pef_Alerting",
                               "Possible values: Yes/No",
-                              0,
+                              verbose_flags,
                               _enable_pef_alerting_checkout,
                               _enable_pef_alerting_commit,
                               config_yes_no_validate) < 0)
     return -1;
 
-  if (config_section_add_key (channel_section,
+  if (config_section_add_key (state_data->pstate,
+                              channel_section,
                               "Non_Volatile_Channel_Privilege_Limit",
                               "Possible values: Callback/User/Operator/Administrator/OEM_Proprietary",
-                              0,
+                              verbose_flags,
                               _channel_privilege_limit_checkout,
                               _channel_privilege_limit_commit,
                               privilege_level_number_validate) < 0)
