@@ -1,6 +1,24 @@
+/* 
+   Copyright (C) 2003-2008 FreeIPMI Core Team
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.  
+*/
+
 #if HAVE_CONFIG_H
 #include "config.h"
-#endif
+#endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -10,6 +28,10 @@
 
 #include "bmc-config-utils.h"
 
+#include "freeipmi-portability.h"
+#include "pstdout.h"
+#include "tool-fiid-wrappers.h"
+
 config_err_t 
 get_lan_channel_number (bmc_config_state_data_t *state_data, uint8_t *channel_num)
 {
@@ -19,13 +41,14 @@ get_lan_channel_number (bmc_config_state_data_t *state_data, uint8_t *channel_nu
       return CONFIG_ERR_SUCCESS;
     }
   
-  if ((state_data->lan_channel_number = ipmi_get_channel_number (state_data->dev, 
+  if ((state_data->lan_channel_number = ipmi_get_channel_number (state_data->ipmi_ctx, 
                                                                  IPMI_CHANNEL_MEDIUM_TYPE_LAN_802_3)) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr, 
-                "ipmi_get_channel_number: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr, 
+                        "ipmi_get_channel_number: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
       return CONFIG_ERR_NON_FATAL_ERROR;
     }
 
@@ -43,13 +66,14 @@ get_serial_channel_number (bmc_config_state_data_t *state_data, uint8_t *channel
       return CONFIG_ERR_SUCCESS;
     }
   
-  if ((state_data->serial_channel_number = ipmi_get_channel_number (state_data->dev, 
+  if ((state_data->serial_channel_number = ipmi_get_channel_number (state_data->ipmi_ctx, 
                                                                     IPMI_CHANNEL_MEDIUM_TYPE_RS232)) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr, 
-                "ipmi_get_channel_number: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr, 
+                        "ipmi_get_channel_number: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
       return CONFIG_ERR_NON_FATAL_ERROR;
     }
 
@@ -73,8 +97,7 @@ get_sol_channel_number (bmc_config_state_data_t *state_data, uint8_t *channel_nu
       return CONFIG_ERR_SUCCESS;
     }
   
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_get_sol_configuration_parameters_sol_payload_channel_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_get_sol_configuration_parameters_sol_payload_channel_rs);
 
   if ((rc = get_lan_channel_number (state_data, &channel_number)) != CONFIG_ERR_SUCCESS)
     {
@@ -82,22 +105,25 @@ get_sol_channel_number (bmc_config_state_data_t *state_data, uint8_t *channel_nu
       goto cleanup;
     }
 
-  if (ipmi_cmd_get_sol_configuration_parameters_sol_payload_channel (state_data->dev,
+  if (ipmi_cmd_get_sol_configuration_parameters_sol_payload_channel (state_data->ipmi_ctx,
                                                                      channel_number,
 								     IPMI_GET_SOL_PARAMETER,
 								     SET_SELECTOR,
 								     BLOCK_SELECTOR,
 								     obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr, 
-                "ipmi_cmd_get_sol_configuration_parameters_sol_payload_channel: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr, 
+                        "ipmi_cmd_get_sol_configuration_parameters_sol_payload_channel: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
   
-  if (Fiid_obj_get(obj_cmd_rs,
+  /* don't use wrapper - non-fatal error */
+  if (fiid_obj_get(obj_cmd_rs,
 		   "payload_channel",
 		   &val) < 0)
     {
@@ -111,7 +137,7 @@ get_sol_channel_number (bmc_config_state_data_t *state_data, uint8_t *channel_nu
   *channel_num = state_data->sol_channel_number;
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return rv;
 }
 
@@ -130,8 +156,7 @@ get_number_of_users (bmc_config_state_data_t *state_data, uint8_t *number_of_use
       return CONFIG_ERR_SUCCESS;
     }
   
-  if (!(obj_cmd_rs = Fiid_obj_create(tmpl_cmd_get_user_access_rs)))
-    goto cleanup;
+  _FIID_OBJ_CREATE(obj_cmd_rs, tmpl_cmd_get_user_access_rs);
 
   if ((rc = get_lan_channel_number (state_data, &channel_number)) != CONFIG_ERR_SUCCESS)
     {
@@ -139,20 +164,23 @@ get_number_of_users (bmc_config_state_data_t *state_data, uint8_t *number_of_use
       goto cleanup;
     }
 
-  if (ipmi_cmd_get_user_access (state_data->dev,
+  if (ipmi_cmd_get_user_access (state_data->ipmi_ctx,
                                 channel_number,
                                 1, /* user_id number */
                                 obj_cmd_rs) < 0)
     {
-      if (state_data->prog_data->args->common.flags & IPMI_FLAGS_DEBUG_DUMP)
-        fprintf(stderr, 
-                "ipmi_cmd_get_user_access: %s\n",
-                ipmi_device_strerror(ipmi_device_errnum(state_data->dev)));
-      rv = CONFIG_ERR_NON_FATAL_ERROR;
+      if (state_data->prog_data->args->config_args.common.debug)
+        pstdout_fprintf(state_data->pstate,
+                        stderr, 
+                        "ipmi_cmd_get_user_access: %s\n",
+                        ipmi_ctx_strerror(ipmi_ctx_errnum(state_data->ipmi_ctx)));
+      if (!IPMI_CTX_ERRNUM_IS_FATAL_ERROR(state_data->ipmi_ctx))
+        rv = CONFIG_ERR_NON_FATAL_ERROR;
       goto cleanup;
     }
   
-  if (Fiid_obj_get(obj_cmd_rs,
+  /* don't use wrapper - non-fatal error */
+  if (fiid_obj_get(obj_cmd_rs,
                    "max_channel_user_ids",
                    &val) < 0)
     {
@@ -166,6 +194,6 @@ get_number_of_users (bmc_config_state_data_t *state_data, uint8_t *number_of_use
   *number_of_users = state_data->number_of_users;
   rv = CONFIG_ERR_SUCCESS;
  cleanup:
-  Fiid_obj_destroy(obj_cmd_rs);
+  _FIID_OBJ_DESTROY(obj_cmd_rs);
   return rv;
 }
