@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmidetect.c,v 1.8 2007/10/18 16:18:49 chu11 Exp $
+ *  $Id: ipmidetect.c,v 1.12 2008/08/12 18:14:39 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -33,6 +33,9 @@
 #if STDC_HEADERS
 #include <string.h>
 #endif /* STDC_HEADERS */
+#if HAVE_STRINGS_H
+#include <strings.h>            /* bzero */
+#endif /* HAVE_STRINGS_H */
 #include <sys/types.h>
 #include <sys/stat.h>
 #if HAVE_FCNTL_H
@@ -63,6 +66,7 @@
 
 #include "conffile.h"
 #include "fd.h"
+#include "freeipmi-portability.h"
 #include "hostlist.h"
 
 /*
