@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmi_monitoring_defs.h,v 1.11 2007/10/18 16:18:49 chu11 Exp $
+ *  $Id: ipmi_monitoring_defs.h,v 1.15 2008/08/25 17:26:24 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2006-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -32,9 +32,7 @@
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <freeipmi/freeipmi.h>
-#include <freeipmi/udm/udm.h>
 
-#include "ipmi_sdr_cache.h"
 #include "list.h"
 
 #ifndef MAXHOSTNAMELEN
@@ -106,7 +104,8 @@
 
 #define IPMI_MONITORING_SENSOR_READING_FLAGS_MASK \
   (IPMI_MONITORING_SENSOR_READING_FLAGS_REREAD_SDR_CACHE \
-   | IPMI_MONITORING_SENSOR_READING_FLAGS_IGNORE_UNREADABLE_SENSORS)
+   | IPMI_MONITORING_SENSOR_READING_FLAGS_IGNORE_UNREADABLE_SENSORS \
+   | IPMI_MONITORING_SENSOR_READING_FLAGS_BRIDGE_SENSORS)
 
 #define IPMI_MONITORING_AUTHENTICATION_TYPE_DEFAULT           IPMI_AUTHENTICATION_TYPE_MD5
 #define IPMI_MONITORING_PRIVILEGE_LEVEL_DEFAULT               IPMI_PRIVILEGE_LEVEL_USER
@@ -120,10 +119,6 @@
 
 #define IPMI_MONITORING_PACKET_BUFLEN 1024
 
-struct ipmi_monitoring_communication {
-  ipmi_device_t dev;
-};
-
 struct ipmi_sensor_config {
   char *option_str;
   int sensor_state;
@@ -151,7 +146,7 @@ struct ipmi_monitoring_ctx {
 
   ipmi_sdr_cache_ctx_t sc;
 
-  struct ipmi_monitoring_communication comm;
+  ipmi_ctx_t ipmi_ctx;
 
   List sensor_readings;
   ListIterator sensor_readings_itr;
