@@ -1,7 +1,7 @@
 /*****************************************************************************\
- *  $Id: ipmipower_connection.h,v 1.9 2007/10/18 16:18:52 chu11 Exp $
+ *  $Id: ipmipower_connection.h,v 1.12 2008/05/17 00:51:22 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2008 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2003-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Albert Chu <chu11@llnl.gov>
@@ -38,20 +38,20 @@ void ipmipower_connection_clear(ipmipower_connection_t ic);
  * - Create ipmipower_connection array
  * - Returns pointer on success, NULL on error.
  */
-struct ipmipower_connection *ipmipower_connection_array_create(hostlist_t hl, 
-                                                               int hl_count);
+struct ipmipower_connection *ipmipower_connection_array_create(const char *hostname,
+                                                               unsigned int *len);
 
 /* ipmipower_connection_array_destroy
  * - Destroy ipmipower_connection array
  */
 void ipmipower_connection_array_destroy(struct ipmipower_connection *ics, 
-                                        int len);
+                                        unsigned int ics_len);
 
 /* ipmipower_connection_hostname_index
  * - Find ics entry with given hostname
  * - Returns index of entry, -1 if not found
  */
 int ipmipower_connection_hostname_index(struct ipmipower_connection *ics,
-                                        int len, char *hostname);
+                                        unsigned int ics_len, char *hostname);
 
 #endif /* _IPMIPOWER_CONNECTION_H */
